from setuptools import setup

setup(name='gaussian_dist',
      version='1.0',
      description='Gaussian and Binomial distributions',
      packages=['gaussian_dist'],
      author = 'Aditya Bisoi',
      zip_safe=False)
